use dotenvy::dotenv;
use entity;
use sea_orm::{Database, DatabaseConnection, EntityTrait};
use std::env;

pub async fn establish_connection() -> DatabaseConnection {
    dotenv().ok();
    let database_url = env::var("DATABASE_URL").expect("DATABASE_URL must be set");
    let db = Database::connect(&database_url).await;
    db.unwrap_or_else(|_| panic!("Error connecting to {}", database_url))
}

#[tokio::main]
async fn main() {
    let connection = establish_connection().await;

    let results = entity::User::find()
        .all(&connection)
        .await
        .expect("Error loading users.");

    println!("Displaying {} users", results.len());
    for user in results {
        println!("{}", user.username);
    }
    println!("-----------\n");
}
